==> prestashop_1.4.0.7.zip: prestashop/modules/statspersonalinfos/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_8063f7c341dbe2cadc294a530cb1cad2'] = 'Información de clientes registrados';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_c11da97e88261de65e614a77cd3358df'] = 'Mostrar características como género y edad';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_0df28a79b0b6ee5f2a91da83bb07117c'] = 'La distribución del género le permite determinar el porcentaje de hombres y de mujeres entre sus clientes.rnrn';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_998e4c5c80f27dec552e99dfed34889a'] = 'CSV Export';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_66ea53c179f966ec08fc4710c60a85be'] = 'El rango de edades le permite determinar en qué gama de edades se encuentran sus clientes.rnrn';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_5186059c6452b447e8253c75b2afac5b'] = 'La distribución por países le permite determinar en qué parte del mundo se encuentran sus clientes.rnrn';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_f761b4cc905eb0fea56adb2bf7f8588f'] = 'Las gamas de monedas le permiten determinar con que moneda pagan sus clientes.rnrn';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_104b6b6b33de198be0f8f3f438171c0f'] = 'La distribución por idiomas le permite determinar el idioma general que hablan los clientes de su tienda.';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_7a7012cc5c52802b45aed45d1f616f1e'] = 'Aún no hay clientes registrados';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_6602bbeb2956c035fb4cb5e844a4861b'] = 'Guía';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_3ca26e413e485538a7f3e610c0324636'] = 'Seleccione su audiencia';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_c8eb1ba430d9ae8fe45fe2d990a481f5'] = 'Para que cada mensaje tenga un impacto, necesita saber a quien va dirigido.';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_e6ef09df5048542d6a707c311661e901'] = 'Dirigirse a la audiencia adecuada es esencial para elegir las herramientas correspondientes para conseguir su objetivo.';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_cb720046e3ddcb4045cb42d996ff1021'] = 'Es preferible limitar la acción a un grupo o grupos de clientes.';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_d002ddab9aa8d394956eadd0bc147dad'] = 'La información de clientes registrados le permite definir con mas exactitud el perfil de cliente típico de modo que usted pueda adaptar sus ofertas a los diferentes criterios.';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_2a1348fc5f72c2fff24ffc3b06bc0f44'] = 'Usted debe utilizar esta información para aumentar sus ventas:rnrn';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_6949590f26952904094acfa988471495'] = 'Lanzando campañas publicitarias dirigidas a clientes específicos que pudieran estar interesados en una oferta particular, en las fechas y horas específicas';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_7878438ad0cb68d43646e19bf8cda504'] = 'Ponerse en contacto con un grupo de clientes por email o a través de la newsletter.';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_8dc514f6da8c696c4a522efc145ad28a'] = 'Distribución del género';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_63889cfb9d3cbe05d1bd2be5cc9953fd'] = 'Hombre';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_b719ce180ec7bd9641fece2f920f4817'] = 'Mujer';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_88183b946cc5f0e8c96b2e66e1c74a7e'] = 'Desconocido';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_0e8cb607499d7862540d5736f6ab84e3'] = 'Rango de edades';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_306fb378f025305fd17ec219fb193797'] = '0-18 años';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_95ad6a8434399a1020f496ae093394a1'] = '18-24 años';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_fb0d334f12a24f10715baef863e20db7'] = '25-34 años';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_268750725a2f1cba57267447006d22ef'] = '35-49 años';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_31974086ef82d676924acbb48fc3de1e'] = '50-59 años';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_e7f407fa37f8cd8c5900329882ad4529'] = '60 años y más';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_73b0130037e21b76351aebfd29d0b9aa'] = 'distribución del país';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_28e81c8343702f6c813cc31a7f90616a'] = 'Distribución de la moneda';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_f1dd68fb6a00d3e4d7f751deacde995d'] = 'Distribución del idioma';

==> prestashop_1.4.0.14.zip: prestashop/modules/statspersonalinfos/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_8063f7c341dbe2cadc294a530cb1cad2'] = 'Información de clientes registrados';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_c11da97e88261de65e614a77cd3358df'] = 'Mostrar características como género y edad';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_0df28a79b0b6ee5f2a91da83bb07117c'] = 'La distribución del género le permite determinar el porcentaje de hombres y de mujeres entre sus clientes.rnrn';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_998e4c5c80f27dec552e99dfed34889a'] = 'CSV Export';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_66ea53c179f966ec08fc4710c60a85be'] = 'El rango de edades le permite determinar en qué gama de edades se encuentran sus clientes.rnrn';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_5186059c6452b447e8253c75b2afac5b'] = 'La distribución por países le permite determinar en qué parte del mundo se encuentran sus clientes.rnrn';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_f761b4cc905eb0fea56adb2bf7f8588f'] = 'Las gamas de monedas le permiten determinar con que moneda pagan sus clientes.rnrn';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_104b6b6b33de198be0f8f3f438171c0f'] = 'La distribución por idiomas le permite determinar el idioma general que hablan los clientes de su tienda.';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_7a7012cc5c52802b45aed45d1f616f1e'] = 'Aún no hay clientes registrados';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_6602bbeb2956c035fb4cb5e844a4861b'] = 'Guía';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_3ca26e413e485538a7f3e610c0324636'] = 'Seleccione su audiencia';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_c8eb1ba430d9ae8fe45fe2d990a481f5'] = 'Para que cada mensaje tenga un impacto, necesita saber a quien va dirigido.';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_52c8c8ae082c162b133883adf411301a'] = 'Dirigirse al público adecuado es primordial para elegir las herramientas correctas para convencer a cada uno de los públicos perseguidos';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_cb720046e3ddcb4045cb42d996ff1021'] = 'Es preferible limitar la acción a un grupo o grupos de clientes.';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_d002ddab9aa8d394956eadd0bc147dad'] = 'La información de clientes registrados le permite definir con mas exactitud el perfil de cliente típico de modo que usted pueda adaptar sus ofertas a los diferentes criterios.';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_2a1348fc5f72c2fff24ffc3b06bc0f44'] = 'Usted debe utilizar esta información para aumentar sus ventas:';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_6949590f26952904094acfa988471495'] = 'Lanzando campañas publicitarias dirigidas a clientes específicos que pudieran estar interesados en una oferta particular, en las fechas y horas específicas';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_7878438ad0cb68d43646e19bf8cda504'] = 'Ponerse en contacto con un grupo de clientes por email o a través de la newsletter.';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_8dc514f6da8c696c4a522efc145ad28a'] = 'Distribución del género';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_63889cfb9d3cbe05d1bd2be5cc9953fd'] = 'Hombre';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_b719ce180ec7bd9641fece2f920f4817'] = 'Mujer';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_88183b946cc5f0e8c96b2e66e1c74a7e'] = 'Desconocido';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_0e8cb607499d7862540d5736f6ab84e3'] = 'Rango de edades';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_306fb378f025305fd17ec219fb193797'] = '0-18 años';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_95ad6a8434399a1020f496ae093394a1'] = '18-24 años';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_fb0d334f12a24f10715baef863e20db7'] = '25-34 años';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_268750725a2f1cba57267447006d22ef'] = '35-49 años';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_31974086ef82d676924acbb48fc3de1e'] = '50-59 años';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_e7f407fa37f8cd8c5900329882ad4529'] = '60 años y más';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_73b0130037e21b76351aebfd29d0b9aa'] = 'distribución del país';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_28e81c8343702f6c813cc31a7f90616a'] = 'Distribución de la moneda';
$_MODULE['<{statspersonalinfos}prestashop>statspersonalinfos_f1dd68fb6a00d3e4d7f751deacde995d'] = 'Distribución del idioma';
